pub struct Register {Show 13 fields
pub cs: Token,
pub address: String,
pub parameters: Option<Parameters>,
pub register_type: RegisterType,
pub readonly: bool,
pub value: Option<RegisterValue>,
pub getter: Option<RegisterGetterClosure>,
pub setter: Option<RegisterSetterClosure>,
pub default: Option<RegisterValue>,
pub mathglyph: Option<char>,
pub role: Option<SymStr>,
pub chardef_props: SymHashMap<Stored>,
pub locator: Locator,
}Expand description
A struct representing a TeX register
Fields
cs: Tokenthe public command sequence for this register
address: Stringthe internal address for this register
parameters: Option<Parameters>associated parameters, if any
register_type: RegisterTypethe type of values accepted by this register (Number, Dimension, …)
readonly: boolread-only flag (default: false)
value: Option<RegisterValue>the current value
getter: Option<RegisterGetterClosure>reader for a value
setter: Option<RegisterSetterClosure>setter for a value
default: Option<RegisterValue>a default value
mathglyph: Option<char>the unicode corresponding to the \mathchar of value (for chardef)
role: Option<SymStr>role attribute for math chardef (e.g. “MULOP”, “BINOP”)
chardef_props: SymHashMap<Stored>additional properties for math chardefs (meaning, stretchy, scriptpos, mathstyle, etc.)
locator: Locatorthe source point of origin for this register definition
Implementations
Sourceimpl Register
impl Register
Sourcepub fn is_readonly(&self) -> bool
pub fn is_readonly(&self) -> bool
checks the readonly flag
Sourcepub fn new_chardef(
cs: Token,
value: Option<RegisterValue>,
mathglyph: Option<char>,
role: Option<SymStr>,
) -> Self
pub fn new_chardef( cs: Token, value: Option<RegisterValue>, mathglyph: Option<char>, role: Option<SymStr>, ) -> Self
A CharDef is a specialized register;
You can’t assign it; when you invoke the control sequence, it returns
the result of evaluating the character (more like a regular primitive).
When mathglyph is provided, it is the unicode corresponding to the \mathchar of value
Sourcepub fn new_math_chardef(
cs: Token,
value: Option<RegisterValue>,
mathglyph: Option<char>,
role: Option<SymStr>,
props: CharDefProps,
) -> Self
pub fn new_math_chardef( cs: Token, value: Option<RegisterValue>, mathglyph: Option<char>, role: Option<SymStr>, props: CharDefProps, ) -> Self
A math CharDef is like a regular CharDef but stores additional decoded math properties (meaning, stretchy, scriptpos, mathstyle, chardef_name, etc.) Perl: LaTeXML::Core::Definition::CharDef->new($cs, ‘math’, $value)
pub fn get_address(&self) -> Cow<'_, str>